/**
 * Classe Contatore
 * @author Daniele Tiles
 * @version 2 04/06/2007
 */
public class Contatore implements Comparable
{
	private int valore, valMax;
	private boolean errore;
	
	/**
	 * Costruttore senza parametri. Il contatore  inizializzato a zero,
	 * e il valore massimo corrisponde al massimo intero con segno.
	 */
	public Contatore()
	{
		valore = 0;
		valMax = Integer.MAX_VALUE;
		errore = false;
	}
	
	/**
	 * Metodo che assegna il valore massimo al contatore.
	 * Se il valore che si presenta e' inferiore o uguale a 0, il contatore transita ina una condizione d'errore.
	 * @param valore valore a cui assegnare il valore massimo
	 */
	public void setMaxVal(int valore)
	{
		if(valore <= 0)
			errore = true;
		else
		    valMax = valore;
	}
	
	/**
	 * Metodo che incrementa il contatore. Se si cerca di incrementare oltre il limite, il contatore entra in uno stato
	 * d'errore
	 */
	public void incrementa()
	{
		if(valore >= valMax)
			errore = true;
		else
		   valore++;
	}
	
	/**
	 * Metodo che "inizializza" il contatore, ovvero il valore attuale e il valore massimo son posti a 0,
	 * lo stato d'errore e' resettato.
	 */
	public void azzera()
	{
		valore = 0;
		valMax = 0;
		errore = false;
	}
	
	
	/**
	 * Metodo che restituisce il valore attuale del contatore.
	 * @return Il valore attuale del contatore.
	 */
	public int leggi()
	{
		return valore;
	}
	
	/**
	 * Metodo che stampa lo stato del contatore (se non si e' in una condizione d'errore, viene
	 * stampato il valore, altrimenti un messaggio d'errore)
	 */
	public void visualizza()
	{
		if(!isError())
		{
			System.out.println("Valore = " + valore);
		}
		else
		{
			System.out.println("Errore!");
		}
	}
	
	/**
	 * Metodo che restituisce se siamo in una condizione d'errore o meno.
	 * @return Lo stato del contatore, siamo in una condizione d'errore?
	 */
	public boolean isError()
	{
		return errore;
	}
	
	
	/**
	 * Metodo specializzato per confrontare due oggetti di tipo Contatore,
	 * si veda il metodo definito sotto
	 * @return Se l'oggetto  pi grande o meno di un altro oggetto
	 */
	public int compareTo(Contatore c)
	{
		return valore - c.valore;
	}
	
	/**
	 * Metodo definito nell'interfaccia Comparable, serve per definire un ordinamento
	 * fra gli oggetti.
	 * Possibili risultati:
	 * -- ==0: I due oggetti son uguali
	 * -- > 0:  L'oggetto su cui richiamiamo questo metodo e' piu' grande dell'oggetto passato
	 * -- < 0:  L'oggetto su cui richiamiamo questo metodo e' piu' piccolo dell'oggetto passato
	 * Il metodo richiama il compareTo(Contatore c)
	 * @return Se l'oggetto  pi grande o meno di un altro oggetto
	 * @see String#toLowerCase()
	 */
	public int compareTo(Object o)
	{
		Contatore c = (Contatore) o;
		return compareTo(c);
	}
}